# -*- coding: utf-8 -*-

###############################################################################
#
# UpdateLabel
# Updates a specific label.
#
# Python versions 2.6, 2.7, 3.x
#
# Copyright 2014, Temboo Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
# either express or implied. See the License for the specific
# language governing permissions and limitations under the License.
#
#
###############################################################################

from temboo.core.choreography import Choreography
from temboo.core.choreography import InputSet
from temboo.core.choreography import ResultSet
from temboo.core.choreography import ChoreographyExecution

import json

class UpdateLabel(Choreography):

    def __init__(self, temboo_session):
        """
        Create a new instance of the UpdateLabel Choreo. A TembooSession object, containing a valid
        set of Temboo credentials, must be supplied.
        """
        super(UpdateLabel, self).__init__(temboo_session, '/Library/Google/Gmailv2/Labels/UpdateLabel')


    def new_input_set(self):
        return UpdateLabelInputSet()

    def _make_result_set(self, result, path):
        return UpdateLabelResultSet(result, path)

    def _make_execution(self, session, exec_id, path):
        return UpdateLabelChoreographyExecution(session, exec_id, path)

class UpdateLabelInputSet(InputSet):
    """
    An InputSet with methods appropriate for specifying the inputs to the UpdateLabel
    Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    """
    def set_AccessToken(self, value):
        """
        Set the value of the AccessToken input for this Choreo. ((optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.)
        """
        super(UpdateLabelInputSet, self)._set_input('AccessToken', value)
    def set_ClientID(self, value):
        """
        Set the value of the ClientID input for this Choreo. ((conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.)
        """
        super(UpdateLabelInputSet, self)._set_input('ClientID', value)
    def set_ClientSecret(self, value):
        """
        Set the value of the ClientSecret input for this Choreo. ((conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.)
        """
        super(UpdateLabelInputSet, self)._set_input('ClientSecret', value)
    def set_Fields(self, value):
        """
        Set the value of the Fields input for this Choreo. ((optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.)
        """
        super(UpdateLabelInputSet, self)._set_input('Fields', value)
    def set_LabelID(self, value):
        """
        Set the value of the LabelID input for this Choreo. ((required, string) The ID of the label to update.)
        """
        super(UpdateLabelInputSet, self)._set_input('LabelID', value)
    def set_LabelListVisibility(self, value):
        """
        Set the value of the LabelListVisibility input for this Choreo. ((required, string) The visibility of the label in the label list in the Gmail web interface. Valid values are: "labelHide", "labelShow", and "labelShowIfUnread.)
        """
        super(UpdateLabelInputSet, self)._set_input('LabelListVisibility', value)
    def set_MessageListVisibility(self, value):
        """
        Set the value of the MessageListVisibility input for this Choreo. ((required, string) The visibility of messages with this label in the message list in the Gmail web interface. Valid values are: "hide" and "show".)
        """
        super(UpdateLabelInputSet, self)._set_input('MessageListVisibility', value)
    def set_Name(self, value):
        """
        Set the value of the Name input for this Choreo. ((required, string) The display name of the label.)
        """
        super(UpdateLabelInputSet, self)._set_input('Name', value)
    def set_RefreshToken(self, value):
        """
        Set the value of the RefreshToken input for this Choreo. ((conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.)
        """
        super(UpdateLabelInputSet, self)._set_input('RefreshToken', value)
    def set_UserID(self, value):
        """
        Set the value of the UserID input for this Choreo. ((optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.)
        """
        super(UpdateLabelInputSet, self)._set_input('UserID', value)

class UpdateLabelResultSet(ResultSet):
    """
    A ResultSet with methods tailored to the values returned by the UpdateLabel Choreo.
    The ResultSet object is used to retrieve the results of a Choreo execution.
    """

    def getJSONFromString(self, str):
        return json.loads(str)

    def get_NewAccessToken(self):
        """
        Retrieve the value for the "NewAccessToken" output from this Choreo execution. ((string) Contains a new AccessToken when the RefreshToken is provided.)
        """
        return self._output.get('NewAccessToken', None)
    def get_Response(self):
        """
        Retrieve the value for the "Response" output from this Choreo execution. ((json) The response from Google.)
        """
        return self._output.get('Response', None)

class UpdateLabelChoreographyExecution(ChoreographyExecution):

    def _make_result_set(self, response, path):
        return UpdateLabelResultSet(response, path)
