# -*- coding: utf-8 -*-

###############################################################################
#
# GetLeadershipByPerson
# Retrieves a list of organizations of which a given person is an executive or board member.
#
# Python versions 2.6, 2.7, 3.x
#
# Copyright 2014, Temboo Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
# either express or implied. See the License for the specific
# language governing permissions and limitations under the License.
#
#
###############################################################################

from temboo.core.choreography import Choreography
from temboo.core.choreography import InputSet
from temboo.core.choreography import ResultSet
from temboo.core.choreography import ChoreographyExecution

import json

class GetLeadershipByPerson(Choreography):

    def __init__(self, temboo_session):
        """
        Create a new instance of the GetLeadershipByPerson Choreo. A TembooSession object, containing a valid
        set of Temboo credentials, must be supplied.
        """
        super(GetLeadershipByPerson, self).__init__(temboo_session, '/Library/LittleSis/Entity/GetLeadershipByPerson')


    def new_input_set(self):
        return GetLeadershipByPersonInputSet()

    def _make_result_set(self, result, path):
        return GetLeadershipByPersonResultSet(result, path)

    def _make_execution(self, session, exec_id, path):
        return GetLeadershipByPersonChoreographyExecution(session, exec_id, path)

class GetLeadershipByPersonInputSet(InputSet):
    """
    An InputSet with methods appropriate for specifying the inputs to the GetLeadershipByPerson
    Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    """
    def set_APIKey(self, value):
        """
        Set the value of the APIKey input for this Choreo. ((required, string) The API Key obtained from LittleSis.org.)
        """
        super(GetLeadershipByPersonInputSet, self)._set_input('APIKey', value)
    def set_Current(self, value):
        """
        Set the value of the Current input for this Choreo. ((optional, integer) Set to 1 to limit the relationships returned to only past relationships. Set to 0 to limit relationships returned to only current relationships. Defaults to all.)
        """
        super(GetLeadershipByPersonInputSet, self)._set_input('Current', value)
    def set_EntityID(self, value):
        """
        Set the value of the EntityID input for this Choreo. ((required, integer) The ID of the person.)
        """
        super(GetLeadershipByPersonInputSet, self)._set_input('EntityID', value)
    def set_ResponseFormat(self, value):
        """
        Set the value of the ResponseFormat input for this Choreo. ((optional, string) Format of the response returned by LittleSis.org. Acceptable inputs: xml or json. Defaults to xml)
        """
        super(GetLeadershipByPersonInputSet, self)._set_input('ResponseFormat', value)
    def set_Type(self, value):
        """
        Set the value of the Type input for this Choreo. ((optional, string) Limits results to organizations of the specified type, e.g. "PublicCompany.")
        """
        super(GetLeadershipByPersonInputSet, self)._set_input('Type', value)

class GetLeadershipByPersonResultSet(ResultSet):
    """
    A ResultSet with methods tailored to the values returned by the GetLeadershipByPerson Choreo.
    The ResultSet object is used to retrieve the results of a Choreo execution.
    """

    def getJSONFromString(self, str):
        return json.loads(str)

    def get_Response(self):
        """
        Retrieve the value for the "Response" output from this Choreo execution. (The response from LittleSis.org.)
        """
        return self._output.get('Response', None)

class GetLeadershipByPersonChoreographyExecution(ChoreographyExecution):

    def _make_result_set(self, response, path):
        return GetLeadershipByPersonResultSet(response, path)
